﻿Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports System.Runtime.CompilerServices

Class MainWindow
    Implements INotifyPropertyChanged
    Private Sub MainWindow_Loaded(sender As Object, e As RoutedEventArgs) Handles Me.Loaded
        AllPersons = New ObservableCollection(Of Person)
        AllPersons.Add(New Person("Max", "Mustermann"))
        AllPersons.Add(New Person("Susi", "Sorglos", PersonGender.Female))
        AllPersons.Add(New Person("Maria", "Musterfrau", PersonGender.Female))
        AllPersons.Add(New Person("Peter", "Hilflos"))

        AllPersonsView = CollectionViewSource.GetDefaultView(AllPersons)
        AllPersonsView.SortDescriptions.Add(New SortDescription("LastName", ListSortDirection.Ascending))
        AllPersonsView.GroupDescriptions.Add(New PropertyGroupDescription("FirstName"))
        AllPersonsView.Filter = AddressOf AllPersonsView_Filter

        Me.DataContext = Me
    End Sub

    Private Function AllPersonsView_Filter(obj As Object) As Boolean
        If String.IsNullOrEmpty(FilterText) Then Return True
        Dim currentPerson As Person = CType(obj, Person)
        Return currentPerson.FullName.ToLower.Contains(FilterText.ToLower)
    End Function

    Private _allPersons As ObservableCollection(Of Person)

    Friend Property AllPersons() As ObservableCollection(Of Person)
        Get
            Return _allPersons
        End Get
        Set(ByVal value As ObservableCollection(Of Person))
            _allPersons = value
            RaisePropertyChanged()
        End Set
    End Property

    Private _allPersonsView As ICollectionView
    Public Property AllPersonsView() As ICollectionView
        Get
            Return _allPersonsView
        End Get
        Set(ByVal value As ICollectionView)
            _allPersonsView = value
            RaisePropertyChanged()
        End Set
    End Property


    Private _filterText As String
    Public Property FilterText() As String
        Get
            Return _filterText
        End Get
        Set(ByVal value As String)
            _filterText = value
            RaisePropertyChanged()
            AllPersonsView.Refresh()
        End Set
    End Property

    Protected Overridable Sub RaisePropertyChanged(<CallerMemberName> Optional ByVal prop As String = "")
        RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(prop))
    End Sub

    Public Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged


End Class
